class Arena extends GameEntity {
  int top = 0, left = 0;
  int width, height;
  ArrayList<AABB> walls;
  
  Arena(int left, int top, int width, int height){
    this.top = top;
    this.left = left;
    this.width = width;
    this.height = height;
    
    walls = new ArrayList<AABB>(3);
    walls.add(new AABB(-1, 0, 0, height));
    walls.add(new AABB(0, -1, width, 0));
    walls.add(new AABB(width, 0, width+1, height));
  }
  
  void draw(){
    noStroke();
    fill(130);
    
    final int wallWidth = 9;
    
    stroke(180);
    strokeWeight(wallWidth);
    line(-wallWidth/2, -wallWidth/2+1, -wallWidth/2, height);
    line(width+wallWidth/2, -wallWidth/2+1, width+wallWidth/2, height);
    line(-wallWidth/2+1, -wallWidth/2, width+wallWidth/2-1, -wallWidth/2);
  }
  
  //Check if the path travelled by the ball touches the arena walls. Notice that the "ball" 
  //is modelled as an axis-aligned square with sides equal to the ball's diameter.
  Collision checkForCollision(PLine path, float radius){
    Collision closestCollision = null;
    for(AABB wall : walls){
      Collision collision = intersectLineWithExpandedAABB(path, wall, radius);
      if ( (collision != null) && ( (closestCollision == null) || (collision.t < closestCollision.t) )){
        closestCollision = collision;
      }
    }
    return closestCollision;
  };
  
  void onCollision(Collision collision, Ball ball){
    state.playSound("hitwall");
  }
}
