//This screen is displayed after the player has cleared all the bricks on the current map.
//Clicking the left mouse button will load the next map, or, if no more maps are available, 
//make the game return to the "intro" state.
class Victory extends GameState {
  PImage gameScreen;
  String nextMapName = null;
  int score, lives;
  float mapTime;
  
  Victory(){
    this(0, 3, 0);
  }
  
  Victory(int totalScore, int remainingLives, float elapsedTime){
    score = totalScore;
    lives = remainingLives;
    mapTime = elapsedTime;
  }
  
  void init(GameEngine game){
    println("Victory : init()");
    
    //Get the current frame to use as the background
    //for the victory screen.
    filter(BLUR);
    gameScreen = get();
    
    //Got another map?
    nextMapName = game.nextMap();
    if ( nextMapName == null ){
      cursor();
    }
  }
  
  void cleanup(){
    println("Victory : cleanup()");
  }
  
  void mouseReleased(GameEngine game){
    if ( mouseButton == LEFT ){
      if ( nextMapName == null ){
        //Back to the intro screen
        game.popState();
        game.changeState(new IntroState());
      } else {
        //Go to the next map (score and remaining lives carry over)
        game.popState();
        game.changeState(new PlayState(nextMapName, score, lives)); 
      }
    }
  }
  
  void draw(GameEngine game){
    background(gameScreen);
    textAlign(LEFT, BASELINE);
    float offset = height/2 - 80;
    
    textSize(48);
    fill(0);
    String message = "VICTORY!";
    text(message, (width - textWidth(message))/2, offset);
    
    //Display the total score, remaining lives and time used to complete the map
    textSize(25);
    float scoreboardOffset = offset + 40;
    fill(130, 0, 0);
    textAlign(RIGHT);
    text("SCORE  ", width/2, scoreboardOffset);
    text("LIVES  ", width/2, scoreboardOffset + 30);
    text("TIME  ", width/2, scoreboardOffset + 60);

    fill(0);
    textAlign(LEFT);
    text(nf(score, 5), width/2, scoreboardOffset);
    text(lives, width/2, scoreboardOffset + 30);
    text(nf(round(mapTime / 60), 2) + ":" + nf(round(mapTime) % 60, 2), width/2, scoreboardOffset + 60);
    
    textSize(24);
    textAlign(LEFT);
    fill(100);
    if ( nextMapName == null ){
      message = "click to return to the intro screen";
    } else {
      message = "click to proceed to the next map";
    }
    text(message, (width - textWidth(message))/2, scoreboardOffset + 95);
  }
}
